@@ -27,17 +27,17 @@ ImageMessage2::ImageMessage2():
 {
   for (int i = 0; i < 3; i ++)
     {
-      dimensions[i] = 0;
-      spacing[i]    = 0.0;
-      subDimensions[i] = 0;
-      subOffset[i] = 0;
+    dimensions[i] = 0;
+    spacing[i]    = 0.0;
+    subDimensions[i] = 0;
+    subOffset[i] = 0;
     }
   for (int i = 0; i < 4; i ++)
     {
-      for (int j = 0; j < 4; j ++)
-        {
-	   matrix[i][j] = (i == j ? 1.0 : 0.0);
-        }
+    for (int j = 0; j < 4; j ++)
+      {
+      matrix[i][j] = (i == j ? 1.0 : 0.0);
+      }
     }
 
   endian        = ENDIAN_BIG;
@@ -47,7 +47,7 @@ ImageMessage2::ImageMessage2():
   m_Image       = NULL;
   numComponents = 1;
 
-  m_DefaultBodyType  = "IMAGE";
+  m_SendMessageType  = "IMAGE";
 
   ScalarSizeTable[0] = 0;
   ScalarSizeTable[1] = 0;
@@ -63,8 +63,8 @@ ImageMessage2::ImageMessage2():
   ScalarSizeTable[11]= sizeof(igtlFloat64); // TYPE_FLOAT64
 
 #ifdef FRAGMENTED_PACK
-  this->m_Header = new unsigned char [IGTL_HEADER_SIZE];
-  this->m_Body   = NULL;
+  this->m_Header  = new unsigned char [IGTL_HEADER_SIZE];
+  this->m_Content = NULL;
 
   this->m_SelfAllocatedImageHeader = 0;
   this->m_ImageSize = 0;
@@ -74,7 +74,7 @@ ImageMessage2::ImageMessage2():
   this->m_SinglePackSize = 0; 
 
   // Size of the pack. Only header can be used after initialization
-  this->m_PackSize = IGTL_HEADER_SIZE;
+  this->m_MessageSize = IGTL_HEADER_SIZE;
 #endif
 
 }
@@ -87,7 +87,7 @@ ImageMessage2::~ImageMessage2()
   //  {
   //  delete [] this->m_Header;
   //  }
-  if (this->m_ImageHeader && this->m_ImageHeader!= this->m_Body && this->m_SelfAllocatedImageHeader)
+  if (this->m_ImageHeader && this->m_ImageHeader!= this->m_Content && this->m_SelfAllocatedImageHeader)
     {
     delete [] this->m_ImageHeader;
     }
@@ -150,17 +150,17 @@ int ImageMessage2::SetSubVolume(int dim[3], int off[3])
       off[1] + dim[1] <= dimensions[1] &&
       off[2] + dim[2] <= dimensions[2])
     {
-      subDimensions[0] = dim[0];
-      subDimensions[1] = dim[1];
-      subDimensions[2] = dim[2];
-      subOffset[0] = off[0];
-      subOffset[1] = off[1];
-      subOffset[2] = off[2];
-      return 1;
+    subDimensions[0] = dim[0];
+    subDimensions[1] = dim[1];
+    subDimensions[2] = dim[2];
+    subOffset[0] = off[0];
+    subOffset[1] = off[1];
+    subOffset[2] = off[2];
+    return 1;
     }
   else
     {
-      return 0;
+    return 0;
     }
 }
 
@@ -171,17 +171,17 @@ int ImageMessage2::SetSubVolume(int dimi, int dimj, int dimk, int offi, int offj
       offj + dimj <= dimensions[1] &&
       offk + dimk <= dimensions[2])
     {
-      subDimensions[0] = dimi;
-      subDimensions[1] = dimj;
-      subDimensions[2] = dimk;
-      subOffset[0] = offi;
-      subOffset[1] = offj;
-      subOffset[2] = offk;
-      return 1;
+    subDimensions[0] = dimi;
+    subDimensions[1] = dimj;
+    subDimensions[2] = dimk;
+    subOffset[0] = offi;
+    subOffset[1] = offj;
+    subOffset[2] = offk;
+    return 1;
     }
   else
     {
-      return 0;
+    return 0;
     }
 }
 
@@ -196,7 +196,7 @@ void ImageMessage2::GetSubVolume(int dim[3], int off[3])
 }
 
 void ImageMessage2::GetSubVolume(int &dimi, int &dimj, int &dimk,
-                                int &offi, int &offj, int &offk)
+                                 int &offi, int &offj, int &offk)
 {
   dimi = subDimensions[0];
   dimj = subDimensions[1];
@@ -366,9 +366,9 @@ void ImageMessage2::AllocateScalars()
   // Memory area to store image scalar is allocated with
   // message and image header, by using AllocatePack() implemented
   // in the parent class.
-
+  
 #ifdef FRAGMENTED_PACK
-
+  MessageBase::AllocateBuffer();
   if (!this->m_ImageHeader)
     {
     this->m_ImageHeader = new unsigned char [IGTL_IMAGE_HEADER_SIZE];
@@ -383,11 +383,11 @@ void ImageMessage2::AllocateScalars()
   this->m_Image = new unsigned char [s];
   this->m_SelfAllocatedImage = 1;
   this->m_ImageSize = s;
-  this->m_PackSize = IGTL_HEADER_SIZE + IGTL_IMAGE_HEADER_SIZE + s;
+  this->m_MessageSize = IGTL_HEADER_SIZE + IGTL_IMAGE_HEADER_SIZE + s;
 
 #else
-  AllocatePack();
-  this->m_ImageHeader = m_Body;
+  AllocateBuffer();
+  this->m_ImageHeader = m_Content;
   this->m_Image  = &m_ImageHeader[IGTL_IMAGE_HEADER_SIZE];
 #endif
 }
@@ -409,22 +409,29 @@ void  ImageMessage2::SetScalarPointer(void * p)
     delete [] this->m_Image;
     }
   this->m_Image = (unsigned char *) p;
+  for (int i = 0;i<IGTL_IMAGE_HEADER_SIZE; i++)
+    {
+    this->m_Content[i] = m_ImageHeader[i];
+    }
+  for (int i = 0;i<GetImageSize(); i++)
+    {
+    this->m_Content[i+IGTL_IMAGE_HEADER_SIZE] = m_Image[i];
+    }
 }
 
 
-void* ImageMessage2::GetPackPointer()
+void* ImageMessage2::GetBufferPointer()
 {
-  // This function is re-implemented for backward compatiblilty.
+  // This function is re-implemented for backward compatibility.
   // If fragmented pack is supported, this function may cause
   // memory copy that may considerably slows the program.
 
   // When the pack only contains header
-  if (this->m_PackSize == IGTL_HEADER_SIZE)
+  if (this->m_MessageSize == IGTL_HEADER_SIZE)
     {
     return this->m_Header;
     }
 
-
   // 
   int vs = this->GetSubVolumeImageSize();
   if (this->m_SinglePackSize < IGTL_HEADER_SIZE + IGTL_IMAGE_HEADER_SIZE + vs)
@@ -437,7 +444,7 @@ void* ImageMessage2::GetPackPointer()
     this->m_SinglePackSize = IGTL_HEADER_SIZE + IGTL_IMAGE_HEADER_SIZE + vs;
     }
     
-    if (this->m_SinglePack == NULL)
+  if (this->m_SinglePack == NULL)
     {
     return NULL;
     }
@@ -494,7 +501,7 @@ int ImageMessage2::GetPackFragmentSize(int id)
 #endif // FRAGMENTED_PACK  
 
 
-int ImageMessage2::GetBodyPackSize()
+int ImageMessage2::CalculateContentBufferSize()
 {
   // This function is called by:
   //   MessageBase::Pack()
@@ -506,49 +513,48 @@ int ImageMessage2::GetBodyPackSize()
 #ifdef FRAGMENTED_PACK  
 int ImageMessage2::Pack()
 {
-  PackBody();
-  m_IsBodyUnpacked   = 0;
+  PackContent();
+  m_IsBodyUnpacked   = false;
   
   // pack header
   igtl_header* h = (igtl_header*) m_Header;
 
   igtl_uint64 crc = crc64(0, 0, 0LL); // initial crc
 
-  h->version   = IGTL_HEADER_VERSION;
+  h->header_version   = IGTL_HEADER_VERSION_1;
 
   igtl_uint64 ts  =  m_TimeStampSec & 0xFFFFFFFF;
   ts = (ts << 32) | (m_TimeStampSecFraction & 0xFFFFFFFF);
 
   h->timestamp = ts;
-  h->body_size = GetBodyPackSize();
+  h->body_size = CalculateContentBufferSize();
 
-  // Note pack fragment #0 is the OpenIGTLink general hearder.
+  // Note pack fragment #0 is the OpenIGTLink general header.
   for (int i = 1; i < this->GetNumberOfPackFragments(); i ++)
     {
     crc = crc64((unsigned char*)this->GetPackFragmentPointer(i),
-                   this->GetPackFragmentSize(i), crc);
+                this->GetPackFragmentSize(i), crc);
     }
   h->crc = crc;
 
-  strncpy(h->name, m_DefaultBodyType.c_str(), 12);
-  // TODO: this does not allow creating pack with MessageBase class...
+  strncpy(h->name, m_SendMessageType.c_str(), 12);
 
   strncpy(h->device_name, m_DeviceName.c_str(), 20);
 
   igtl_header_convert_byte_order(h);
 
-  m_IsHeaderUnpacked = 0;
+  m_IsHeaderUnpacked = false;
 
   return 1;
 }
 #endif // FRAGMENTED_PACK  
 
 
-int ImageMessage2::PackBody()
+int ImageMessage2::PackContent()
 {
   igtl_image_header* image_header = (igtl_image_header*)this->m_ImageHeader;
 
-  image_header->version           = IGTL_IMAGE_HEADER_VERSION;
+  image_header->header_version    = IGTL_IMAGE_HEADER_VERSION;
   image_header->num_components    = this->numComponents;
   image_header->scalar_type       = this->scalarType;
   image_header->endian            = this->endian;
@@ -569,10 +575,10 @@ int ImageMessage2::PackBody()
   float norm_k[3];
 
   for (int i = 0; i < 3; i ++) {
-    norm_i[i] = matrix[i][0];
-    norm_j[i] = matrix[i][1];
-    norm_k[i] = matrix[i][2];
-    origin[i] = matrix[i][3];
+  norm_i[i] = matrix[i][0];
+  norm_j[i] = matrix[i][1];
+  norm_k[i] = matrix[i][2];
+  origin[i] = matrix[i][3];
   }
 
   igtl_image_set_matrix(this->spacing, origin,
@@ -586,7 +592,7 @@ int ImageMessage2::PackBody()
 }
 
 
-int ImageMessage2::UnpackBody()
+int ImageMessage2::UnpackContent()
 {
   if (this->m_ImageHeader && this->m_SelfAllocatedImageHeader)
     {
@@ -599,81 +605,81 @@ int ImageMessage2::UnpackBody()
     this->m_SelfAllocatedImage = 0;
     }
 
-  this->m_ImageHeader = this->m_Body;
+  this->m_ImageHeader = this->m_Content;
 
   igtl_image_header* image_header = (igtl_image_header*)m_ImageHeader;
   igtl_image_convert_byte_order(image_header);
 
-  if (image_header->version == IGTL_IMAGE_HEADER_VERSION)
+  if (image_header->header_version == IGTL_IMAGE_HEADER_VERSION)
     {
-      // Image format version 1
-      this->scalarType       = image_header->scalar_type;
-      this->numComponents    = image_header->num_components;
-      this->endian           = image_header->endian;
-      this->coordinate       = image_header->coord;
-      this->dimensions[0]    = image_header->size[0];
-      this->dimensions[1]    = image_header->size[1];
-      this->dimensions[2]    = image_header->size[2];
-      this->subOffset[0]     = image_header->subvol_offset[0];
-      this->subOffset[1]     = image_header->subvol_offset[1];
-      this->subOffset[2]     = image_header->subvol_offset[2];
-      this->subDimensions[0] = image_header->subvol_size[0];
-      this->subDimensions[1] = image_header->subvol_size[1];
-      this->subDimensions[2] = image_header->subvol_size[2];
+    // Image format version 1
+    this->scalarType       = image_header->scalar_type;
+    this->numComponents    = image_header->num_components;
+    this->endian           = image_header->endian;
+    this->coordinate       = image_header->coord;
+    this->dimensions[0]    = image_header->size[0];
+    this->dimensions[1]    = image_header->size[1];
+    this->dimensions[2]    = image_header->size[2];
+    this->subOffset[0]     = image_header->subvol_offset[0];
+    this->subOffset[1]     = image_header->subvol_offset[1];
+    this->subOffset[2]     = image_header->subvol_offset[2];
+    this->subDimensions[0] = image_header->subvol_size[0];
+    this->subDimensions[1] = image_header->subvol_size[1];
+    this->subDimensions[2] = image_header->subvol_size[2];
 
-      // Set image orientation
-      float rspacing[3];
-      float origin[3];
-      float norm_i[3];
-      float norm_j[3];
-      float norm_k[3];
+    // Set image orientation
+    float rspacing[3];
+    float origin[3];
+    float norm_i[3];
+    float norm_j[3];
+    float norm_k[3];
 
-      igtl_image_get_matrix(rspacing, origin,
-                            norm_i, norm_j, norm_k,
-                            image_header);
+    igtl_image_get_matrix(rspacing, origin,
+                          norm_i, norm_j, norm_k,
+                          image_header);
 
-      for (int i = 0; i < 3; i ++) {
-        this->spacing[i] = rspacing[i];
-        matrix[i][0] = norm_i[i];
-        matrix[i][1] = norm_j[i];
-        matrix[i][2] = norm_k[i];
-        matrix[i][3] = origin[i];
+    for (int i = 0; i < 3; i ++)
+      {
+      this->spacing[i] = rspacing[i];
+      matrix[i][0] = norm_i[i];
+      matrix[i][1] = norm_j[i];
+      matrix[i][2] = norm_k[i];
+      matrix[i][3] = origin[i];
       }
 
-      matrix[3][0] = 0.0;
-      matrix[3][1] = 0.0;
-      matrix[3][2] = 0.0;
-      matrix[3][3] = 1.0;
+    matrix[3][0] = 0.0;
+    matrix[3][1] = 0.0;
+    matrix[3][2] = 0.0;
+    matrix[3][3] = 1.0;
 
-      this->m_Image = this->m_ImageHeader;
-      this->m_Image += IGTL_IMAGE_HEADER_SIZE;
+    this->m_Image = this->m_ImageHeader;
+    this->m_Image += IGTL_IMAGE_HEADER_SIZE;
       
-      return 1;
+    return 1;
     }
   else
     {
-      // Incompatible version. 
-      return 0;
+    // Incompatible version. 
+    return 0;
     }
 }
 
-
 #ifdef FRAGMENTED_PACK  
-void ImageMessage2::AllocatePack(int bodySize)
+void ImageMessage2::AllocateBuffer(int contentSize)
 {
-
-  if (bodySize <= 0)
+  MessageBase::AllocateBuffer(contentSize);
+  if (contentSize <= 0)
     {
-    bodySize = 0;
-    this->m_IsBodyUnpacked = 0;
+    contentSize = 0;
+    this->m_IsBodyUnpacked = false;
     }
 
-  int s = IGTL_HEADER_SIZE + bodySize;
+  int s = IGTL_HEADER_SIZE + contentSize;
 
-  m_IsHeaderUnpacked = 0;
-  m_IsBodyUnpacked = 0;
+  m_IsHeaderUnpacked = false;
+  m_IsBodyUnpacked = false;
 
-  if (bodySize > 0)
+  if (contentSize > 0)
     {
     if (this->m_ImageHeader && this->m_SelfAllocatedImageHeader)
       {
@@ -689,24 +695,23 @@ void ImageMessage2::AllocatePack(int bodySize)
       }
     if (this->m_Body)
       {
-      if (this->m_PackSize != s)
+      if (this->m_MessageSize != s)
         {
         // If the pack area exists but needs to be reallocated
         // m_IsHeaderUnpacked status is not changed in this case.
         unsigned char * old = this->m_Body;
-        this->m_Body = new unsigned char [bodySize];
-        memcpy(this->m_Body, old, bodySize);
+        this->m_Body = new unsigned char [contentSize];
+        memcpy(this->m_Body, old, contentSize);
         delete [] old;
         }
       }
     else 
       {
-      this->m_Body = new unsigned char [bodySize];
+      this->m_Body = new unsigned char [contentSize];
       }
-    this->m_PackSize = s;
+    this->m_MessageSize = s;
     }
 }
-
 #endif // FRAGMENTED_PACK  
 
 
@@ -726,6 +731,3 @@ int ImageMessage2::GetNumComponents()
 
 
 } // namespace igtl
-
-
-
