@@ -37,6 +37,9 @@ class IGTLCommon_EXPORT MessageHandler: public Object
 
  public:
   virtual const char* GetMessageType() { return ""; }
+#if OpenIGTLink_HEADER_VERSION >= 2
+  virtual std::string GetMessageType() const { return std::string(""); }
+#endif
   virtual int ReceiveMessage(Socket*, MessageBase*, int) { return 0; };
 
   void SetMessageBuffer(MessageBase* buffer) { this->m_Buffer = buffer; }
