@@ -420,10 +420,9 @@ int PolyDataAttribute::GetNthData(unsigned int n, igtlFloat32 * data)
 
 // Description:
 // PolyDataMessage class implementation
-PolyDataMessage::PolyDataMessage():
-  MessageBase()
+PolyDataMessage::PolyDataMessage()
 {
-  this->m_DefaultBodyType = "POLYDATA";
+  this->m_SendMessageType = "POLYDATA";
   Clear();
 }
 
@@ -490,17 +489,6 @@ void IGTLCommon_EXPORT SetPolyDataInfo(igtl_polydata_info * info, PolyDataMessag
     info->header.ntriangle_strips = 0;
     info->header.size_triangle_strips = 0;
     }
-    
-  if (pdm->GetPolygons())
-    {
-    info->header.npolygons = pdm->GetPolygons()->GetNumberOfCells();
-    info->header.size_polygons = pdm->GetPolygons()->GetTotalSize();
-    }
-  else
-    {
-    info->header.npolygons = 0;
-    info->header.size_polygons = 0;
-    }
 
   info->header.nattributes = pdm->GetNumberOfAttributes();
 
@@ -570,11 +558,11 @@ void IGTLCommon_EXPORT UnSetPolyDataInfoAttribute(igtl_polydata_info * info)
 }
 
 
-int PolyDataMessage::GetBodyPackSize()
+int PolyDataMessage::CalculateContentBufferSize()
 {
   // TODO: The current implementation of GetBodyPackSize() allocates
   // igtl_polydata_info and the array of igtl_polydata_attribute to calculate
-  // the size of pack. However, this approach is not efficent because
+  // the size of pack. However, this approach is not efficient because
   // it causes unnecessary memory allocation. 
 
   int dataSize;
@@ -585,7 +573,7 @@ int PolyDataMessage::GetBodyPackSize()
   // Instead of calling igtl_polydata_alloc_info(), we only allocate
   // memory for the attribute array, since igtl_polydata_alloc_info()
   // allocates also allocates the memory area for actual points and
-  // cell data, which is not neccessary to calculate polydata size.
+  // cell data, which is not necessary to calculate polydata size.
 
   info.attributes = new igtl_polydata_attribute[info.header.nattributes];
   
@@ -616,14 +604,14 @@ int PolyDataMessage::GetBodyPackSize()
   //delete [] (info.attributes);
   delete [] info.attributes;
 
-  return  dataSize;
+  return dataSize;
 }
 
 
-int PolyDataMessage::PackBody()
+int PolyDataMessage::PackContent()
 {
-  // Allocate pack
-  AllocatePack();
+  // Allocate buffer
+  AllocateBuffer();
 
   igtl_polydata_info info;
 
@@ -649,10 +637,6 @@ int PolyDataMessage::PackBody()
       *(ptr_f++) = points[2];
       }
     }
-  else
-    {
-    return 0;
-    }
 
   //Vertices
   if (info.vertices)
@@ -708,20 +692,25 @@ int PolyDataMessage::PackBody()
 
   SetPolyDataInfoAttribute(&info, this);
 
-  igtl_polydata_pack(&info, this->m_Body, IGTL_TYPE_PREFIX_NONE);
+  igtl_polydata_pack(&info, this->m_Content, IGTL_TYPE_PREFIX_NONE);
+  
   igtl_polydata_free_info(&info);
 
   return 1;
 }
 
 
-int PolyDataMessage::UnpackBody()
+int PolyDataMessage::UnpackContent()
 {
   igtl_polydata_info info;
 
   igtl_polydata_init_info(&info);
+  
+  int r = 0;
 
-  if (igtl_polydata_unpack(IGTL_TYPE_PREFIX_NONE, (void*)this->m_Body, &info, this->GetPackBodySize()) == 0)  
+  r = igtl_polydata_unpack(IGTL_TYPE_PREFIX_NONE, (void*)this->m_Content, &info, this->CalculateReceiveContentSize());
+
+  if ( r == 0)
     {
     return 0;
     }
@@ -890,9 +879,56 @@ PolyDataAttribute * PolyDataMessage::GetAttribute(unsigned int id)
   return this->m_Attributes[id];
 }
 
-} // namespace igtl
+GetPolyDataMessage::GetPolyDataMessage()
+{
+  this->m_SendMessageType  = "GET_POLYDATA";
+}
 
+bool RTSPolyDataMessage::GetStatus() const
+{
+  return m_Status == 1;
+}
 
+void RTSPolyDataMessage::SetStatus(bool status)
+{
+  m_Status = status ? 1 : 0;
+}
 
+int RTSPolyDataMessage::CalculateContentBufferSize()
+{
+  return sizeof(igtl_uint8);
+}
 
+int RTSPolyDataMessage::PackContent()
+{
+  AllocateBuffer();
 
+  igtl_uint8* content;
+  // Copy data
+#if OpenIGTLink_HEADER_VERSION >= 2
+  content = this->m_Content;
+#else
+  content = this->m_Body;
+#endif
+
+  *content = m_Status;
+
+  return 1;
+}
+
+int RTSPolyDataMessage::UnpackContent()
+{
+  igtl_uint8* content;
+
+#if OpenIGTLink_HEADER_VERSION >= 2
+  content = this->m_Content;
+#else
+  content = this->m_Body;
+#endif
+
+  this->m_Status = *content;
+
+  return 1;
+}
+
+} // namespace igtl
\ No newline at end of file
