@@ -17,19 +17,19 @@
 #ifndef __IGTL_TEST_DATA_BIND_H
 #define __IGTL_TEST_DATA_BIND_H
 
-char test_bind_message_header[] = {
+unsigned char test_bind_message_header[] = {
   0x00, 0x01,                                     /* Version number */
   0x42, 0x49, 0x4e, 0x44, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00,                         /* BIND */ 
   0x44, 0x65, 0x76, 0x69, 0x63, 0x65, 0x4e, 0x61,
   0x6d, 0x65, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00,                         /* Device name */
-  0x00, 0x00, 0x00, 0x00, 0x49, 0x96, 0x02, 0xd2, /* Time stamp */
+  0x00, 0x00, 0x00, 0x00, 0x49, 0x96, 0x02, 0xd4, /* Time stamp */
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0a, 0xd8, /* Body size */
   0xd3, 0x4d, 0x56, 0xba, 0x63, 0xaf, 0x8a, 0x6a, /* CRC */
 };
 
-char test_bind_message_bind_header[] = {          /* 98 bytes */
+unsigned char test_bind_message_bind_header[] = {          /* 98 bytes */
 
   0x00, 0x03,                                     /* Number of child messages */
 
@@ -56,7 +56,7 @@ char test_bind_message_bind_header[] = {          /* 98 bytes */
 };
 
 
-char test_bind_message_bind_body[] = {            /* 48+2572+58 = 2678 bytes */
+unsigned char test_bind_message_bind_body[] = {            /* 48+2572+58 = 2678 bytes */
   
   /* TRANSFORM */
   0xBF, 0x74, 0x73, 0xCD, 0x3E, 0x49, 0x59, 0xE6, /* tx, ty */
